@@ -25,8 +25,8 @@ class View(object):
 
     def to_file(self):
         # fichier de propriétés
-        if not os.path.exists(self.view_dir):
-            os.makedirs(self.view_dir)
+        if not os.path.exists(self.view_dir.encode('utf-8')):
+            os.makedirs(self.view_dir.encode('utf-8'))
         file = open("{}/PROPERTIES.md".format(self.view_dir), 'w+', encoding='utf-8')
         with file:
             # nom de l'objet
