@@ -61,8 +61,8 @@ class BaseField(object):
 
     def create_dir(self):
         # fichier de propriétés
-        if not os.path.exists(self.field_dir):
-            os.makedirs(self.field_dir)
+        if not os.path.exists(self.field_dir.encode('utf-8')):
+            os.makedirs(self.field_dir.encode('utf-8'))
 
     def to_file(self):
         with open("{}/PROPERTIES.md".format(self.field_dir), 'w+', encoding='utf-8') as file:
