@@ -39,8 +39,8 @@ class Section(object):
 
     def to_file(self):
         # fichier de propriétés
-        if not os.path.exists(self.section_directory):
-            os.makedirs(self.section_directory)
+        if not os.path.exists(self.section_directory.encode('utf-8')):
+            os.makedirs(self.section_directory.encode('utf-8'))
         with open("{}/PROPERTIES.md".format(self.section_directory), 'w+', encoding='utf-8') as file:
             # nom de l'objet
             file.write("# {}\n".format(self.section_title))
