@@ -29,8 +29,8 @@ class WebPageDef(object):
         self.page_directory = "{}/pages/{}".format(app_directory, dirname)
 
     def to_file(self):
-        if not os.path.exists(self.page_directory):
-            os.makedirs(self.page_directory)
+        if not os.path.exists(self.page_directory.encode('utf-8')):
+            os.makedirs(self.page_directory.encode('utf-8'))
 
         # fichier de propriétés
         with open("{}/PROPERTIES.md".format(self.page_directory), 'w+', encoding='utf-8') as file:
